package com.ruoyi.system.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.RlFunction;
import com.ruoyi.system.domain.device.EDevice;
import com.ruoyi.system.domain.model.EModel;
import com.ruoyi.system.domain.model.RlModelVO;
import com.ruoyi.system.mapper.EModelMapper;
import com.ruoyi.system.service.IEDeviceService;
import com.ruoyi.system.service.IEModelService;
import com.ruoyi.system.service.IRlFunctionService;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;

/**
 * 车辆型号Service业务层处理
 *
 * @author 邱贞招
 * @date 2024-05-13
 */
@Slf4j
@Service
public class EModelServiceImpl implements IEModelService
{
    @Resource
    private EModelMapper eModelMapper;

    @Autowired
    private IEDeviceService eDeviceService;

    @Autowired
    private IRlFunctionService rlFunctionService;


    /**
     * 查询车辆型号
     *
     * @param modelId 车辆型号主键
     * @return 车辆型号
     */
    @Override
    public RlModelVO selectEModelByModelId(Long modelId)
    {
        RlModelVO etModel = eModelMapper.selectEModelByModelId(modelId);
//        if(ObjectUtil.isNotNull(etModel)){
//            Integer allNum = eDeviceService.selectCountByModelId(modelId);
//            etModel.setDeviceNum(allNum);
//        }
        return etModel;
    }

    /**
     * 查询车辆型号列表
     *
     * @param eModel 车辆型号
     * @return 车辆型号
     */
    @Override
//    @DataScope(deptAlias = "d")
    public List<EModel> selectEModelList(EModel eModel)
    {
        List<EModel> etModels = eModelMapper.selectEModelList(eModel);
        for(EModel model: etModels){
            // 投放数量统计
            EDevice device = new EDevice();
            device.setModelId(model.getModelId());
//            Integer integer = eDeviceService.selectCountByModelId(model.getModelId());
//            model.setDeviceNum(integer);
        }
        return etModels;
    }

    /**
     * 新增车辆型号
     *
     * @param etModel 车辆型号
     * @return 结果
     */
    @SneakyThrows
    @Override
    @Transactional
    public int insertEModel(EModel etModel)
    {
        etModel.setCreateTime(DateUtils.getNowDate());
        int i = eModelMapper.insertEModel(etModel);
        return i;
    }

    /**
     * 修改车辆型号
     *
     * @param etModel 车辆型号
     * @return 结果
     */
    @SneakyThrows
    @Override
    @Transactional
    public int updateEModel(EModel etModel)
    {
        etModel.setUpdateTime(DateUtils.getNowDate());
        int i = eModelMapper.updateEModel(etModel);
        return i;
    }

    /**
     * 批量删除车辆型号
     *
     * @param modelIds 需要删除的车辆型号主键
     * @return 结果
     */
    @Override
    public int deleteEModelByModelIds(Long[] modelIds)
    {
        return eModelMapper.deleteEModelByModelIds(modelIds);
    }

    /**
     * 删除车辆型号信息
     *
     * @param modelId 车辆型号主键
     * @return 结果
     */
    @Override
    public int deleteEModelByModelId(Long modelId)
    {
        return eModelMapper.deleteEModelByModelId(modelId);
    }

    @Override
    public int selectAllCount() {
        return eModelMapper.selectAllCount();
    }

    /**
     * 根据车型id获取功能
     */
    @Override
    public List<RlFunction> getFunctionListByModelId(Long modelId) {
        return rlFunctionService.selectRlFunctionByModelId(modelId);
    }


}
