package com.ruoyi.system.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.userWithdraw.RlUserWithdraw;
import com.ruoyi.system.mapper.RlUserWithdrawMapper;
import com.ruoyi.system.service.IRlUserWithdrawService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 用户提现渠道Service业务层处理
 *
 * @author qzz
 * @date 2024-10-21
 */
@Service
public class RlUserWithdrawServiceImpl implements IRlUserWithdrawService
{
    @Resource
    private RlUserWithdrawMapper rlUserWithdrawMapper;

    /**
     * 查询用户提现渠道
     *
     * @param userChannelId 用户提现渠道主键
     * @return 用户提现渠道
     */
    @Override
    public RlUserWithdraw selectRlUserWithdrawByUserChannelId(Long userChannelId)
    {
        return rlUserWithdrawMapper.selectRlUserWithdrawByUserChannelId(userChannelId);
    }

    /**
     * 查询用户提现渠道列表
     *
     * @param rlUserWithdraw 用户提现渠道
     * @return 用户提现渠道
     */
    @Override
    public List<RlUserWithdraw> selectRlUserWithdrawList(RlUserWithdraw rlUserWithdraw)
    {
        return rlUserWithdrawMapper.selectRlUserWithdrawList(rlUserWithdraw);
    }

    /**
     * 根据userId查询用户提现渠道列表
     *
     * @param userId 用户id
     * @return 用户提现渠道集合
     */
    @Override
    public List<RlUserWithdraw> selectRlUserWithdrawListByUserId(Long userId) {
        return rlUserWithdrawMapper.selectRlUserWithdrawListByUserId(userId);
    }

    /**
     * 新增用户提现渠道
     *
     * @param rlUserWithdraw 用户提现渠道
     * @return 结果
     */
    @Override
    public int insertRlUserWithdraw(RlUserWithdraw rlUserWithdraw)
    {
        rlUserWithdraw.setCreateTime(DateUtils.getNowDate());
        return rlUserWithdrawMapper.insertRlUserWithdraw(rlUserWithdraw);
    }

    /**
     * 修改用户提现渠道
     *
     * @param rlUserWithdraw 用户提现渠道
     * @return 结果
     */
    @Override
    public int updateRlUserWithdraw(RlUserWithdraw rlUserWithdraw)
    {
        return rlUserWithdrawMapper.updateRlUserWithdraw(rlUserWithdraw);
    }

    /**
     * 批量删除用户提现渠道
     *
     * @param userChannelIds 需要删除的用户提现渠道主键
     * @return 结果
     */
    @Override
    public int deleteRlUserWithdrawByUserChannelIds(Long[] userChannelIds)
    {
        return rlUserWithdrawMapper.deleteRlUserWithdrawByUserChannelIds(userChannelIds);
    }

    /**
     * 删除用户提现渠道信息
     *
     * @param userChannelId 用户提现渠道主键
     * @return 结果
     */
    @Override
    public int deleteRlUserWithdrawByUserChannelId(Long userChannelId)
    {
        return rlUserWithdrawMapper.deleteRlUserWithdrawByUserChannelId(userChannelId);
    }
}
